@@ -1,9 +1,9 @@
-# Copyright (C) 2022 Panther Labs Inc
+# Copyright (C) 2022 Panther Labs, Inc.
 #
-# Panther Enterprise is licensed under the terms of a commercial license available from
-# Panther Labs Inc ("Panther Commercial License") by contacting contact@runpanther.com.
-# All use, distribution, and/or modification of this software, whether commercial or non-commercial,
-# falls under the Panther Commercial License to the extent it is permitted.
+# The Panther SaaS is licensed under the terms of the Panther Enterprise Subscription
+# Agreement available at https://panther.com/enterprise-subscription-agreement/.
+# All intellectual property rights in and to the Panther SaaS, including any and all
+# rights to access the Panther SaaS, are governed by the Panther Enterprise Subscription Agreement.
 
 # coding=utf-8
 # *** WARNING: generated file
@@ -22,23 +22,23 @@ __all__ = [
     "AnyFilter",
     "AnyUnitTest",
     "DynamicStringField",
-    "DynamicStringFieldOptions",
+    "DynamicStringFieldOverrides",
     "DynamicDestinations",
-    "DynamicDestinationsOptions",
+    "DynamicDestinationsOverrides",
     "AlertGrouping",
-    "AlertGroupingOptions",
+    "AlertGroupingOverrides",
     "PythonFilter",
-    "PythonFilterOptions",
+    "PythonFilterOverrides",
     "UnitTestMock",
-    "UnitTestMockOptions",
+    "UnitTestMockOverrides",
     "JSONUnitTest",
-    "JSONUnitTestOptions",
+    "JSONUnitTestOverrides",
     "Policy",
-    "PolicyOptions",
+    "PolicyOverrides",
     "Rule",
-    "RuleOptions",
+    "RuleOverrides",
     "ScheduledRule",
-    "ScheduledRuleOptions",
+    "ScheduledRuleOverrides",
     "SeverityLow",
     "SeverityInfo",
     "SeverityMedium",
@@ -57,8 +57,8 @@ ReportKeyMITRE = "MITRE ATT&CK"
 
 
 @dataclasses.dataclass
-class DynamicStringFieldOptions:
-    """Options dataclass for DynamicStringField. All arguments are marked optional.
+class DynamicStringFieldOverrides:
+    """Overrides dataclass for DynamicStringField. All arguments are marked optional.
 
     - fallback -- Fallback value in case the dynamic handler fails
     - func -- Dynamic handler
@@ -95,8 +95,8 @@ class DynamicStringField(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class DynamicDestinationsOptions:
-    """Options dataclass for DynamicDestinations. All arguments are marked optional.
+class DynamicDestinationsOverrides:
+    """Overrides dataclass for DynamicDestinations. All arguments are marked optional.
 
     - func -- Dynamic handler
     - fallback -- Fallback value in case the dynamic handler fails
@@ -133,8 +133,8 @@ class DynamicDestinations(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class AlertGroupingOptions:
-    """Options dataclass for AlertGrouping. All arguments are marked optional.
+class AlertGroupingOverrides:
+    """Overrides dataclass for AlertGrouping. All arguments are marked optional.
 
     - group_by -- Function to generate a key for grouping matches
     - period_minutes -- How long should matches be grouped into an alert after the first match
@@ -171,8 +171,8 @@ class AlertGrouping(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class PythonFilterOptions:
-    """Options dataclass for PythonFilter. All arguments are marked optional.
+class PythonFilterOverrides:
+    """Overrides dataclass for PythonFilter. All arguments are marked optional.
 
     - func -- Provide a function whose python source will be used as the filter definition
     """
@@ -202,8 +202,8 @@ class PythonFilter(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class UnitTestMockOptions:
-    """Options dataclass for UnitTestMock. All arguments are marked optional.
+class UnitTestMockOverrides:
+    """Overrides dataclass for UnitTestMock. All arguments are marked optional.
 
     - name -- name of the object to mock
     - return_value -- string to assign as the return value for the mock
@@ -240,8 +240,8 @@ class UnitTestMock(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class JSONUnitTestOptions:
-    """Options dataclass for JSONUnitTest. All arguments are marked optional.
+class JSONUnitTestOverrides:
+    """Overrides dataclass for JSONUnitTest. All arguments are marked optional.
 
     - data -- json string
     - expect_match -- whether the data should match and trigger an alert
@@ -292,8 +292,8 @@ class JSONUnitTest(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class PolicyOptions:
-    """Options dataclass for Policy. All arguments are marked optional.
+class PolicyOverrides:
+    """Overrides dataclass for Policy. All arguments are marked optional.
 
     - filters -- Define event filters for the policy
     - policy_id -- ID for the Policy
@@ -475,8 +475,8 @@ class Policy(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class RuleOptions:
-    """Options dataclass for Rule. All arguments are marked optional.
+class RuleOverrides:
+    """Overrides dataclass for Rule. All arguments are marked optional.
 
     - filters -- Define event filters for the rule
     - log_types -- Log Types to associate with this rule
@@ -666,8 +666,8 @@ class Rule(_utilities.SDKNode):
 
 
 @dataclasses.dataclass
-class ScheduledRuleOptions:
-    """Options dataclass for ScheduledRule. All arguments are marked optional.
+class ScheduledRuleOverrides:
+    """Overrides dataclass for ScheduledRule. All arguments are marked optional.
 
     - filters -- Define event filters for the scheduled rule
     - rule_id -- ID for the scheduled rule
